@@ -820,22 +820,27 @@ windViewCmd(w, cmd)
 
 	if (!strncmp(cmd->tx_argv[1], "get", 3))
 	{
+	    char *vllx, *vlly, *vurx, *vury;
+
+	    vllx = DBWPrintValue(w->w_surfaceArea.r_xbot, w, TRUE);
+	    vlly = DBWPrintValue(w->w_surfaceArea.r_ybot, w, FALSE);
+	    vurx = DBWPrintValue(w->w_surfaceArea.r_xtop, w, TRUE);
+	    vury = DBWPrintValue(w->w_surfaceArea.r_ytop, w, FALSE);
+
 	    /* NOTE:  The surface area is in screen (pixel) coordinates
 	     * and so does not follow the "units" display type.
 	     */
 #ifndef MAGIC_WRAPPER
-	    TxPrintf("(%d, %d) to (%d, %d)\n",
-			w->w_surfaceArea.r_xbot, w->w_surfaceArea.r_ybot,
-			w->w_surfaceArea.r_xtop, w->w_surfaceArea.r_ytop);
+	    TxPrintf("(%s, %s) to (%s, %s)\n", vllx, vlly, vurx, vury);
 #else
 	    Tcl_ListObjAppendElement(magicinterp, listxy,
-			Tcl_NewIntObj((int)w->w_surfaceArea.r_xbot));
+			Tcl_NewStringObj(vllx, -1));
 	    Tcl_ListObjAppendElement(magicinterp, listxy,
-			Tcl_NewIntObj((int)w->w_surfaceArea.r_ybot));
+			Tcl_NewStringObj(vlly, -1));
 	    Tcl_ListObjAppendElement(magicinterp, listxy,
-			Tcl_NewIntObj((int)w->w_surfaceArea.r_xtop));
+			Tcl_NewStringObj(vurx, -1));
 	    Tcl_ListObjAppendElement(magicinterp, listxy,
-			Tcl_NewIntObj((int)w->w_surfaceArea.r_ytop));
+			Tcl_NewStringObj(vury, -1));
 	    Tcl_SetObjResult(magicinterp, listxy);
 #endif
 	}
